
import pygame
from pygame.locals import *

import qgl
import qgle

# this magic number corresponds to the max vertical coordinate of the playfield plane
# with a z-value of -20
playfield_size_multiplier = 8.28

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world

def viewport_coords_for_mouse_coords(viewport, mousepos):
    #print "mousepos:", mousepos
    newx = mousepos[0] - viewport.screen_dimensions[2]/2
    newy = viewport.screen_dimensions[3] - mousepos[1]
    newy = newy - viewport.screen_dimensions[3]/2
    newx *= playfield_size_multiplier*2.0/viewport.screen_dimensions[3]
    newy *= playfield_size_multiplier*2.0/viewport.screen_dimensions[3]
    #print "viewportpos:", [newx, newy]
    return [newx, newy]

def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    playfield = qgl.scene.Group()
    playfield.translate = 0.0, 0.0, -20.0
    world.add(playfield)
    
    points = (-1,-1,0),(-0.9,1,0),(0.9,1,0),(1,-1,0),(-1,-1,0)#, (0.9,1.0), (0.95, 0.0), (-0.95, 0.0), (-0.9, 1.0), (0.9, -1.0)
    vehicle = qgl.scene.Group(qgl.scene.state.Polyline(points))
    vehicle.translate = 0.0, 7.0, 0.0
    playfield.add(vehicle)
    
    points = (-0.5, -1.2,0),(-0.5, 1.2,0),(0.5, 1.2,0),(0.5, -1.2,0),(-0.5, -1.2,0)#,(0.5,1.2)
    wall1 = qgl.scene.Group(qgl.scene.state.Polyline(points))
    wall1.translate = 10.0,7.0,0.0
    wall2 = qgl.scene.Group(qgl.scene.state.Polyline(points))
    wall2.translate = -10.0,7.0,0.0
    walls = qgl.scene.Group(wall1, wall2)
    playfield.add(walls)
    
    shotgroup = qgl.scene.Group()
    playfield.add(shotgroup)

    root_node.accept(compiler)
    
    vehicle.velocity = (0.0,0.0,0.0,0.0)
    vehicle.acceleration = (0.0,0.0,0.0,0.0)
    vehicle.drag = 0.01
    prev_vehicle_translate = vehicle.translate

    keynames = {97:'A', 119:"W", 100:"D", 115:"S", 32:"space", 27:"esc", 273:"uparrow", \
        274:"downarrow", 276:"leftarrow", 275:"rightarrow"}
        
    prev_collide_count = 0
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                print clock.get_fps()
                if event.key == 27: 
                    return
                elif keynames[event.key] == "leftarrow":
                    set_vehicle_horizontal_acceleration(vehicle, -45)
                elif keynames[event.key] == "rightarrow":
                    set_vehicle_horizontal_acceleration(vehicle, 45)
            elif event.type is KEYUP:
                if keynames[event.key] in ["leftarrow", "rightarrow"]:
                    set_vehicle_horizontal_acceleration(vehicle, 0)
            elif event.type is MOUSEBUTTONDOWN:
                fire_shot_from_vehicle(vehicle, viewport_coords_for_mouse_coords(viewport, event.pos), shotgroup)
                #picker.set_position(event.pos)
                #root_node.accept(picker)
                #for hit in  picker.hits:
                #    hit.angle += 10

        root_node.accept(render)
        qgle.drive(root_node, clock.tick(60) / 1000.0)
        
        # delete off-screen shots
        if len(shotgroup.branches)>0:
            onscreen_shots = qgle.collide(playfield.translate, 14.0, shotgroup)
            print len(onscreen_shots), "of", len(shotgroup.branches), "are on-screen"
        
        position = vehicle.translate[0:3]
        # see if we collided with a wall.  If so, stop the vehicle dead in its tracks
        colliding_nodes = qgle.collide(position, 1.5, walls)
        curr_collide_count = len(colliding_nodes)
        if curr_collide_count != prev_collide_count:
            print "colliding with", len(colliding_nodes), "nodes at", position
            prev_collide_count = curr_collide_count
        if curr_collide_count>0:
            vehicle.velocity = (0.0,0.0,0.0,0.0)
            vehicle.acceleration = (0.0,0.0,0.0,0.0)
            vehicle.translate = prev_vehicle_translate
        else:
            prev_vehicle_translate = vehicle.translate
            
        pygame.display.flip()
        

def set_vehicle_horizontal_acceleration(vehicle, h):
    acceleration = [h, vehicle.acceleration[1], vehicle.acceleration[2], vehicle.acceleration[3]]
    vehicle.acceleration = acceleration    

shotpoints = (-0.2, 0.0, 0.0), (0.2, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.2, 0.0), (0.0, -0.2, 0.0)
def fire_shot_from_vehicle(vehicle, mouseloc, parent):
    if mouseloc[1] >= vehicle.translate[1]:
        return
    shot = qgl.scene.Group(qgl.scene.state.Polyline(shotpoints))
    shot.translate = vehicle.translate
    parent.add(shot)
    print "firing from", vehicle.translate[0:2], "to", mouseloc
    xvel = 0.0
    yvel = -7.0
    if mouseloc[1]!=vehicle.translate[1]:
        xvel = (vehicle.translate[0]-mouseloc[0])/(vehicle.translate[1]-mouseloc[1])
        xvel *= yvel
    shot.velocity = (xvel, yvel, 0.0, 900.0)
        
main()
