#How do I display a picture on the screen?


import pygame
from pygame.locals import *

import qgl
import qgle
    

def main():
    #setup pygame as normal, making sure to include the OPENGL flag in the init function arguments.
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    
    #Create two visitors.
    #The compiler visitor is used to change a Node object into a set of OpenGL draw commands. More on nodes later.
    compiler = qgl.render.Compiler()
    #The render visitor is used to execute compiled commands.
    render = qgl.render.Render()
    
    #the root node is the root of the tree structure (also called a scene graph). Branches get added to the root. 
    root_node = qgl.scene.Root()
    
    #every root node must have a viewport branch, which specified which area of the screen to draw to.
    #the OrthoViewport renders all its children in a flat, orthographic view.
    viewport = qgl.scene.OrthoViewport()
    viewport.screen_dimensions = (0,0,800,600)
    
    #a group node can translate, rotate and scale its children. it can also contain leaves, which are drawable things.
    group = qgl.scene.Group()
    
    #leaves are added to the group. The texture leaf loads a texture image ready for drawing. Any quads leaves, which are drawn 
    #after a texture or color leaf will be rendered with the texture image.
    texture = qgl.scene.state.Texture("land.jpg")
    #A color leaf has 4 color components red, green, blue and alpha (opacity)
    color = qgl.scene.state.Color((1.0,1.0,1.0,1.0))
    quad = qgl.scene.state.Quad((200,200))
            
    #Now we add the different nodes and leaves into a tree structure using the .add method.
    root_node.add(viewport)
    viewport.add(group)
    group.add(texture, color, quad)
    
    #Before the structure can be drawn, it needs to be compiled. To do this, we ask the root node to accept the compiler visitor.
    #If any new nodes are added later in the program, they must also accept the compiler visitor before they can be drawn.
    root_node.accept(compiler)
    
    #the variable will be used to set the alpha component of the color leaf.
    #by decrementing the alpha value slowly, all quad leaves rendered after the color leaf will fade away.
    alpha = 1.0
    
    clock = pygame.time.Clock()
    #the main render loop
    while True:
        #process pygame events.
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                return
        
        #decrement the alpha value
        alpha -= 0.01
        #set the color leaf to a new rgba value
        color.rgba = (1.0,1.0,1.0,alpha)
        #ask the root node to accept the render visitor. This will draw the structure onto the screen.
        #notice that QGL draws everything from the centre, and that the 0,0 point in a QGL screen is the center of the screen.
        root_node.accept(render)
        
        #limit the FPS to 30
        clock.tick(30)
        #flip the display
        pygame.display.flip()


main()

