#!/usr/bin/python

#Splits a file into tiles, and packs into a QGL sequence.

import sys
import getopt
import glob

import pygame
from pygame.locals import *
import qgl.tools

def usage():
    print "Usage: split -w [width] -h [height] -p [output_file_prefix] image_file"
    

def main():
    defaults = {'-w':32,'-h':32, '-p':'sequence'}
    try:
        opts, args = getopt.getopt(sys.argv[1:], "w:h:p:", ["help", "output="])
    except getopt.GetoptError:
        # print help information and exit:
        usage()
        sys.exit(2)
    defaults.update(opts)
    try:
        defaults['-w'] = int(defaults['-w'])
        defaults['-h'] = int(defaults['-h'])
        defaults['-p'] = str(defaults['-p'])
    except ValueError:
        usage()
        sys.exit(2)
    pygame.init()
    pygame.display.init()
    tileset = pygame.image.load(args[0])
    screen = pygame.display.set_mode((tileset.get_width(), tileset.get_height()))
    screen.blit(tileset, (0,0))
    pygame.display.flip()
    x,y = 0,0
    name,w,h = defaults['-p'],defaults['-w'], defaults['-h']
    frame = 0
    while True:
        tile = screen.subsurface((x,y,w,h))
        filename = "%s_%s.tga" % (name, frame)
        print filename, tile.get_width(), tile.get_height()
        pygame.image.save(tile, filename)
        tile.fill((0,0,0))
        pygame.display.flip()
        frame += 1
        x += w
        if x+w > tileset.get_width():
            x = 0
            y += h
        if y+h > tileset.get_height():
            break
    
    #use the qgl.tools.make_sequence function to pack all split images into a sequence file.
    qgl.tools.make_sequence("%s_*.tga" % name, "%s_packed" % name)
        
    
if __name__ == "__main__":
    main()