
import pygame
from pygame.locals import *

import qgl
import qgle

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world

def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    
    text = qgl.scene.Group(qgl.scene.state.Text("test", "mono.ttf"))
    world.foreground.add(text)
    text.selectable = True
    text.velocity = (0.0,0.0,0.0,0.0)
    text = qgl.scene.Group(qgl.scene.state.Text("test", "mono.ttf"))
    world.foreground.add(text)
    text.selectable = True
    text.translate = (0.0,-2.0,0.0)
    text.velocity = (0.0,0.0,0.0,0.0)
    
    root_node.accept(compiler)
    
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                print clock.get_fps()
                if event.key == 27: 
                    return
            elif event.type is MOUSEBUTTONDOWN:
                picker.set_position(event.pos)
                root_node.accept(picker)
                for hit in  picker.hits:
                    hit.acceleration = (0.0,0.0,0.0,0.01)
        root_node.accept(render)
        qgle.drive(root_node)
        clock.tick(60)
        pygame.display.flip()
        
        
main()
