
import pygame
from pygame.locals import *

import qgl

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    world.environment = qgl.scene.Group()
    world.add(world.environment)
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world

def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    
    texture = qgl.scene.state.Texture("data/r2station.jpg")
    mesh = qgl.scene.state.Mesh("data/r2station.obj")
    model = qgl.scene.Group(texture,mesh)
    light = qgl.scene.state.Light(position=(0,10,0))
    model.update(translate=(0,0,-80))
    world.environment.add(light)
    world.environment.add(model)
    
    
    
    root_node.accept(compiler)
    
    speed = [1.0]
    
    def move_in():
        x,y,z = model.translate
        z += 1.0
        model.translate = x,y,z
        
    def move_out():
        x,y,z = model.translate
        z -= 1.0
        model.translate = x,y,z
        
    def redisplay():
        del texture.texture
        del mesh.list
        model.accept(compiler)
        
    def faster():
        speed[0] += 1
        
    def slower():
        speed[0] -= 1
        
    def pause():
        speed[0] = 0
    
    def switch_light():
        if light in world.environment.leaves:
            world.environment.remove(light)
        else:
            world.environment.add(light)
            
        print world.environment
        
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                if event.key == 27: 
                    print clock.get_fps()
                    return
                else:
                    redisplay()
                
                if event.unicode == ' ':
                    pause()
                elif event.unicode == 'q':
                    faster()
                elif event.unicode == 'a':
                    slower()
                elif event.unicode == 'l':
                    switch_light()
                    
            elif event.type is MOUSEBUTTONDOWN:
                
                if event.button == 4: #SCROLL UP
                    move_in()
                elif event.button == 5: #SCROLL DOWN
                    move_out()
                else:
                    pass
                
                
        
        model.axis = (1,1,0)
        model.angle += speed[0]
        root_node.accept(render)
        clock.tick(30)
        pygame.display.flip()
        
        
main()
